Crate kcr_trace_kubeblocks_io

Crate kcr_trace_kubeblocks_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the trace.kubeblocks.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

trace.kubeblocks.io/v1

  • ReconciliationTrace

Modules

v1